
#' @title Plot a rich box plot of a numerical response variable as a function
#'  of a numerical grouping variable
#' @name MLA.boxplot
#' @param y a numerical response variable
#' @param group a numerical grouping variable
#' @param lines0  if \code{lines0=TRUE} a line connecting means is drawn
#' @param line.color color of the lines
#' @param box if \code{box=TRUE} box are drawn
#' @param facwidth a factor for scaling box widths (it adjusts the internal \code{boxplot} \code{boxwex} in pars list)
#' @param spline if TRUE a spline smoothing is performed (with cross validation). Default is TRUE)
#' @param ... other graphical parameters 
#'
#' @return a list with \code{y} means, grouping values, sizes 
#' @export
#'
#' @examples \donttest{
#' myplot.grouped.bin}
MLA.boxplot=function(y,group,lines0=TRUE,box=TRUE,line.color=2,facwidth=3,spline=TRUE,...){
  ##
  lwd2=1
  col2=4
  m1  =lm(y~group)
  xg  =sort(unique(group))
  med =tapply(y,group,mean)
  ng  =tapply(y,group,length)
  xg  =as.numeric(names(med))
  
  plot(group,y,cex=0.5,col=2,xlab=deparse(substitute(group)),ylab=deparse(substitute(y)),main="Boxplot, regression line, linear regression",...)
  boxwex=facwidth/length(xg)
  if (box) boxplot(y~group,at=xg,range=0,add=TRUE,pars=list(boxwex=boxwex) )
  if (lines0) lines(xg,med)
  points(xg,med,pch=1,col=line.color)
  x=seq(min(group),max(group),by=0.05)
  
  l1=m1$coefficients[1]+m1$coefficients[2]*x
  lines(x,l1,col=line.color)
  if(spline)    lines(smooth.spline(med~xg,w=ng,cv=TRUE), lwd=lwd2, col=col2)
  
  return(list(m=med,x=xg ))
}
