#' @title Histogram, non parametric density, normal density
#' @details The function plots the histogram of the distribution of the input variable
#' together with a non parametric estimate of the density and
#'   a normal density. Possibly \code{x} is a vector of 
#'   \code{lm$residuals}. 
#' @description  Join to MLA.plot.feq some day...
#' @param z input numerical variable 
#' @param nc number of classes for histogram
#' @param std if \code{std=TRUE} then variable 
#' is standardized before plotting
#' @param p if a number is supported then a norm-p density is also plotted
#' (not yet supported)
#' @param pML if \code{pML=TRUE} then a norm-p density is also plotted
#' (not yet supported)
#'
#' @return plots the histogram of the distribution of the input variable
#' together with a non parametric estimate of the density and
#'   a normal density (and optionally a norm-p density).
#'
#' @examples MLA.plot.norm(rnorm(1000))
#' MLA.plot.norm(rgamma(1000,shape=2))
MLA.plot.norm<-function(z,nc=50,std=FALSE,p=NULL,pML=FALSE){
  zname=deparse1(substitute(z))
  # plots histogram, non parametric density, normal density
  if(std) z=scale(z)
  hist(z,nc=nc,probability  = TRUE, main=paste("distribution of ",zname,"; n=",length(z),sep=""))
    lines(density(z),col=4)
    m   =mean(z)
    s   =sd(z)
    zx=seq(-4*s+m,4*s+m,by=0.05)
    lines(zx,dnorm(zx,mean=m,sd=s),col=2)
    ## future: chi square
    ## future: norm p density
    if(pML){
      ris=estimatepmLM(z)$estimate
      p  =ris[1]
        m  =ris[2]
        s  =std.dev.p(z,p)
        lines(zx,dnormp(zx,m=m,s=s,p=p),col=3)
        }
}