#' @title Compute bivariate normal density
#'
#' @param x x-values of points
#' @param y y-values of points
#' @param s1 standard deviation of the first variable (x)
#' @param s2 standard deviation of the second variable (y)
#' @param m1 expected value of the first variable (x)
#' @param m2 expected value of the second variable (x)
#' @param r theoretical correlation
#'
#' @return a vector of bivariate normal densities
#' @export
#'
#' @examples
dnormbiv= function(x,y,s1=1,s2=1,m1=0,m2=0,r=0) {
z1=(x-m1)/s1
z2=(y-m2)/s2
exp(-0.5*(z1*z1+z2*z2-2*r*z2*z1)/(1-r*r))/(2*pi*s1*s2*sqrt(1-r*r))
}
