#' @title Fast computation of the means of a numerical response
#' variable as a function  of a numerical grouping variable
#' @param y a numerical response variable
#' @param group a numerical grouping variable
#' @details Substantially equivalent to \code{tapply(y,group,MEAN)}, but faster, 
#' because group is ordered with index before computing means. Return indeces can be used to 
#' compute other function on groups, like sd or var, etc...
#' @return a list with:
#' values of \code{y} ordered  according the values of \code{group}
#' \code{k} number of categories of \code{group}
#' a vector \code{lim} of index the boundaries of \code{y} belonging to the same group
#' \code{n} number of elements of \code{y}
#' \code{m} array of the \code{k} means of  \code{y} as a function of \code{group}

#' @export
#'
#' @examples
group.optim= function(y,group=array(1,length(y))){
n   =length(y)
lim =c(0,n)
if(sd(group)>0){
    ord =order(as.integer(group))
    y   =y[ord]
    wd  =which(diff(group[ord])>0)
    lim =c(0,wd,n)
    rm(ord)
}
k   =length(lim)-1
lim1=lim[1:k]+1
lim2=lim[2:(k+1)]
m   =array(0,k)
for(j in 1:k) m[j]<-mean(y[lim1[j]:lim2[j]])
return(list(y=y,lim=lim,k=k,n=n,m=m))
}
