
#' @title impute.cat.simple
#' @aliases impute.cat.simple
#' @description Very simple imputation method for factor variables. 
#'  The companion function for numerical variables is \code{impute.num.simple} 
#' @param y a factor of \code{n} elements and {k} modalities with possible missing data
#' @param rule possible values are \code{"missing.asnewmod"} and \code{random}
#' @details according to \code{rule} the missing values are replaced by a new category 
#' \code{ismissing} when \code{rule}= \code{"missing.asnewmod"}; 
#' missing values are replaced by a random sample (with replacement) of non missing values 
#' of \code{y} when \code{rule}= \code{"random"}.
#' 
#' At the moment (september 2020) possible values are \code{"missing.asnewmod"} and \code{random}
#' @return the factor \code{y} with imputed missing values. 
#' @export
#'
#' @examples
impute.cat.simple<-function(y,rule="missing.asnewmod"){
  ind.miss=is.na(y)
  if(sum(as.numeric(ind.miss))>0){
    y[ind.miss]=
    switch(rule,
           missing.asnewmod = "ismissing",
           random = sample(y[!ind.miss],sum(ind.miss),replace=TRUE))
  }
    return(y)
}
