#' @title impute.matrix.mixed
#' @aliases impute.matrix.mixed
#' @description Very simple imputation method for mixed variables. 
#'  For factors  \code{impute.cat.simple} is used, while \code{impute.num.simple}
#'  is used for numerical variables
#' @param x A matrix with numerical variables and factors with missing values
#' @param rule possible values are \code{"fixed"} and \code{"random"}
#' @param max.iter maximum numbers of iterations
#' @param max.err max error (evaluated only for numerical variables)
#' @details For factors  \code{impute.cat.simple} is used, while \code{impute.num.simple}
#'  is used for numerical variables. Imputation of numerical variables  is iterated until convergence.
#  In future a version a random assignment of missing values,
#' conditioned to other variables, will be implemented, with \code{rule}=\code{"random"}
#' @return the matrix \code{x} with imputed missing values. 
impute.matrix.mixed<-function(x, rule="fixed",max.iter=5, max.err=0.000001){
  n     =nrow(x)
  k     =ncol(x)
  mat.miss=is.na(x)
  is.fac  =numeric(0)
  for (j in 1:k)is.fac[j]=is.factor(x[,j])
  
  ##
  ## first round of imputation
  ##
  for (j in 1:k){
    z=x[,j]
    if (is.fac[j]){
    z=  impute.cat.simple(z,rule="missing.asnewmod")
    }
    else
    {
    z=  impute.num.simple(z,rule="mean.subst")
    }
    x[,j]=z
  }
  iter=0
  ##
  ## cycle of imputation only for numerical variables
  ##
  while(iter<max.iter){
    iter=iter+1
    cat("iter ",iter)
    print("")
    delta=0
    k.num=sum(as.numeric(!is.fac))
    for (j in 1:k){
      z=x[,j]
      ind=1:k
      ind=ind[-j]
      if (!is.fac[j]){
        ind=ind[!is.fac[-j]]
        is.na(z)[mat.miss[,j]]=TRUE # restore original missing values
      z=  impute.num.simple(z,rule="cond.mean.num",x=x[,ind])
      delta=delta+sum(abs(x[,j]-z))/sum(abs(x[,j]-mean(abs(x[,j]))))
      x[,j]=z
      }
    }
    cat("delta ",delta/k.num)
  }
  return(x)}
