
#' @title impute.num.simple
#' @aliases impute.num.simple
#' @description Very simple imputation method for numerical variables. 
#'  The companion function for factors is \code{impute.cat.simple} 
#' @param y a numerical variable of \code{n} elements  with possible missing data
#' @param rule possible values are \code{"mean.subst"}, \code{"random"} and  \code{"cond.mean.num"}
#' @param x a matrix  with \code{n} rows 
#' @details according to \code{rule} the missing values are replaced by 
#' the average of remaining values when \code{rule}=
#' \code{"mean.subst"}, or  
#' missing values are replaced by a random sample (with replacement) of non missing values of \code{y}
#' when \code{rule}= \code{"random"} or missing valuese are replaced by a linear predictor based on 
#' other numerical variables present in \code{x} when \code{rule}=\code{"cond.mean.num"}.
#' 
#' At the moment (september 2020) possible values are \code{"mean.subst"}, \code{random}
#' and \code{"cond.mean.num"}.
#' @return the factor \code{y} with imputed missing values. 
#' @export
#'
#' @examples

impute.num.simple<-function(y,rule="mean.subst",x=NULL){
  ind.miss=is.na(y)
  if(sum(as.numeric(ind.miss))>0){
  y[ind.miss]=
    switch(rule,
           mean.subst = mean(y[!ind.miss]),
           random = sample(y[!ind.miss],sum(ind.miss),replace=TRUE),
           cond.mean.num = predict(lm(y[!ind.miss]~.,data=as.data.frame(x[!ind.miss,])),
                               newdata=as.data.frame(x[ind.miss,])))
  }
  return(y)
}

