#' @title lines3d.marginal
#' @description Draws a 2d line on a costant plane in a 3d (existing) plot. The plane can also be plotted.
#' Any of the six coordinate plane can be chosen with \code{plane}, together with the level at which it must be fixed.
#' @param x x-values 
#' @param y y-values (of the same length of \code{x})
#' @param z Costant value of the third variable at which the 2d line must be plotted. 
#' @param plane the coordinate plane used for the plot. Six values are possible: "xy","xz","yx","yz","zx","zy".
#'  The choice will set the right permutation of the input \code{x,y,z} 
#' @param zrange The range of the third variable (to use only if \code{newplot=TRUE})
#' @param newplot if \code{TRUE}, a new 3d window is opened
#' @param color.lines color of the line 
#' @param color.points color of the points 
#' @param display.line If \code{TRUE} the line is plotted on the plane \code{plane}
#' @param display.plane If \code{TRUE} the plane  \code{plane} is explicitely rendered
#' @param display.points If \code{TRUE} points are plotted on the plane  \code{plane} 
#' @param display.grid If \code{TRUE} a grid is plotted on the plane  \code{plane} 
#' @param ngrid approximate number of grid lines to be plotted on the plane  \code{plane} 
#' @param color.plane Color of the plotted plane
#' @param alpha Transparency level of the plane 
#' @param clipping.plane (not yet implemented)
#' @param ... Other graphical parameters
#'
#' @value no value is returned. Only plotting
#' @export
#'
#' @examples
lines3d.marginal<-function(x,y,z=0,plane="xy",zrange=c(-10,10),newplot=FALSE,color.lines=4,color.points=2,
                           display.line=TRUE,display.points=TRUE,display.plane=TRUE, display.grid=FALSE,ngrid=10,color.plane="blue",alpha=0.2,clipping.plane=FALSE,...){
  
  ind.axes=switch(plane,
                  "xy"=c(1,2,3),
                  "xz"=c(1,3,2),
                  "yx"=c(2,1,3),
                  "yz"=c(3,1,2),
                  "zx"=c(2,3,1),
                  "zy"=c(3,2,1))

     ind2=ind.axes         
              
  ## which(ind.axes==3) determines which is the variable to be keept constant
  
  if (display.grid) {
    pretx<-pretty(x,n=ngrid)
    prety<-pretty(y,n=ngrid)
    x0=min(pretx)
    y0=min(prety)
    rangetot=rbind(c(x0,y0,min(zrange)),c(max(pretx),max(prety),max(zrange)))

    }
  else 
    {
    rangetot=rbind(c(min(x),min(y),min(zrange)),c(max(x),max(y),max(zrange)))
    }
  
  rangetot=rangetot[,ind.axes]
  
  matl=cbind(x,y,array(z,length(x)))
  matl=matl[,ind.axes]
  param.plane=c(0,0,0,z)
  param.plane[which(ind.axes==3)]=-1
  ## ind.axes determines which is the order of variables for the 2d graph on a 3d plane
  lab=colnames(matl)

  if(newplot) plot3d(NULL,NULL,NULL, xlim=rangetot[,1],ylim=rangetot[,2],zlim=rangetot[,3],xlab=lab[1],ylab=lab[2],zlab=lab[3])
 ### to be completed 
  
  if(display.plane) planes3d(param.plane[1],param.plane[2],param.plane[3],param.plane[4]
                             ,alpha=alpha,color=color.plane)
  
  if (display.line) lines3d(matl,color=color.lines,...)
  
  if (display.points) points3d(matl,color=color.points,...)

  if (display.points) points3d(matl,color=color.points,...)
  
  if (display.grid) {

  vec1=c("pretx","y0","z")
  vec2=c("0","1","0")
  
  
  e1=paste(vec1[ind2],collapse=",")
  e2=paste(vec2[ind2],collapse=",")
  expr2=paste(e1,e2,"col=8)",sep=",")
  expr2=paste("abclines3d",expr2,sep="(")
  eval(parse(text=expr2))        ##############
  
  
  vec1=c("x0","prety","z")
  vec2=c("1","0","0")
  e1=paste(vec1[ind2],collapse=",")
  e2=paste(vec2[ind2],collapse=",")
  expr1=paste(e1,e2,"col=8)",sep=",")
  expr1=paste("abclines3d",expr1,sep="(")
  eval(parse(text=expr1))

  }
  
  
  
  
  if(clipping.plane){}
  
}

