#' @title Compute the ROC curve and AUC value 
#' @aliases my.auc plot.auc
#' @param pred a numerical predictor
#' @param target a 0/1 variable, of the same length \code{n} of the \code{predictor}
#' @usage my.auc(pred,target)
#' @usage \method{plot}{auc}(x,...)
#' @param x  An \code{auc} object. \code{plot.auc(x)}  will plot the curve
#' @param ...  other plotting options
#' @return an object of \code{auc} class with following components: \code{x,y} coordinates
#'  of the ROC curve \code{auc} Area Under the Curve
#' 
#' @export
#'
#' @examples
  my.auc=function(pred,target){
  target   =target[order(pred)]
  n   =length(target)
  totP=sum(target)
  totN=n-totP
  FN  =cumsum(target)
  TN  =(1:n)-FN
  FP  =totN-TN 
  TP  =n-totN-FN
  x   =c(1,FP/(TN+FP))
  y   =c(1,TP/(FN+TP))
  auc =-0.5*sum(diff(x)*(y[-1]+y[-n]))
  obj=list(auc=auc,x=x,y=y)
  class(obj)		="auc"
  
  return(obj)
}
plot.auc<-function(x,...){
  if(class(x)!="auc")stop("argument must be an auc object")
  
  with(x,plot(x,y,type="l",col=2,lwd=3,
                xaxs="i",yaxs="i",
                xlab="False Positive Rate",
                ylab="True Positive Rate",
                main=paste("ROC Curve. AUC=",round(obj$auc,3))))
  xp=c(x$x,0,1,1)
  yp=c(x$y,0,0,1)
  polygon(xp, yp , density = NA, angle = 45,
          border = 2, col = "yellow")
  abline(a=0,b=1)
  
}
