#' @title reduced.inv
#' @description Given a symmetric matrix and its inverse, computes efficiently the inverse of a submatrix of 
#' the input matrix with a row and a column dropped
#' @param r a numeric matrix
#' @param r.inv the inverse of \code{r}
#' @param j the row and column index that must be dropped out from \code{r}
#' @details Much faster than inversion of the submatrix. There is however no control on numerical precision, so
#' avoid to use it recursively to go, for example from a 1000x1000 matrix to a 990x990 inverse in 10 steps.
#' @return The inverse of \code{r} without the \code{j-th} row and the \code{j-th} column
#' @export

reduced.inv<-function(r,r.inv,j=1){
  B=r.inv[-j,-j]
  return(B+outer(r.inv[j,-j],as.vector(crossprod(r[j,-j],B)))/(r[j,j]*r.inv[j,j]))
}
