#' @title Simple grafic bivariate regression simulation
#' @description very simple 3d rendering of a simulation of bivariate linear regression (with two explicative variables x1, x2). Correlation between x1 and x2 can be chosen.
#' @param nsample number of samples (and planes) to simulate
#' @param tpause second of pause between samples
#' @param n single sample size
#' @param beta0 true value of intercept
#' @param beta1 true value of regression coefficient for \code{x1}
#' @param beta2 true value of regression coefficient for \code{x2}
#' @param rho.x1x2 correlation between regressors x1,x2
#' @return a list with simulated estimates and the X matrix used 
#' @export
#'
#' @examples
simulreg3d=function(nsample=1,tpause=0.05,	n=10,beta0=1,beta1=0.8,beta2=0.7,rho.x1x2=0.1
){
  nsample=trunc(nsample)
    s=c(1,1)
		m1=matrix(c(s[1]^2,rho.x1x2*s[1]*s[2],rho.x1x2*s[1]*s[2],s[2]^2),2,2)
	x=rmvnorm(n=n,mean=c(0,0), sigma=m1)
	colnames(x)=c("x1","x2")
	ey=beta0+beta1*x[,1]+beta2*x[,2]
	
#par(mfrow=c(1,2))
	x1range=enlarged.range(x[,1],eps=0.2)
	x2range=enlarged.range(x[,2],eps=0.2)
	yrange=enlarged.range(ey,eps=0.4)

	MLA.regression3d(cbind(x,ey),level=0.99,ell=FALSE,conf.exp = FALSE,alpha.plane = 0.8)
	
if(nsample<1)return("Wrong number of samples")
x=	as.data.frame(x)

b.simulated=numeric(0)
for (i in 1:nsample){
	y=ey+rnorm(n)
	l1=lm(y~x1+x2,data=x)
	MLA.regression3d(cbind(x,y),newplot=FALSE,points.observed=FALSE,ell=FALSE,conf.exp = FALSE,alpha.plane = 0.25)
	b.simulated=rbind(b.simulated,coef(l1))
	Sys.sleep(tpause)
}
#plot(b.simulated[,2:3],xlab="b1",ylab="b2",
#     main=c("Simulated sampling distribution of b1 and b2",
#            paste("estimated on ",nsample, " simulated planes. r(x1,x2)=",rho.x1x2,"; r(b1,b2)=",
#                  cor(b.simulated[,2:3])))   )
plot(b.simulated[,2:3],xlab="b1",ylab="b2",
     main=c("Simulated sampling distribution of b1 and b2",
            paste("estimated on ",nsample, " simulated planes"))   )


abline(v=beta1)
abline(h=beta2)
return(list(matb=b.simulated,matx=x))
}


